<?php

namespace Drupal\commerce_sameday\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\commerce_order\Entity\OrderInterface;

/**
 * Controller for customer-facing Sameday tracking tab.
 */
class SamedayCustomerTrackingController extends ControllerBase {

  /**
   * Displays Sameday tracking info for a customer order.
   */
  public function tracking(OrderInterface $commerce_order) {
    $shipments = $commerce_order->get('shipments')->referencedEntities();
    $tracking_blocks = [];
    foreach ($shipments as $shipment) {
      $awb = $shipment->getData('sameday_awb');
      if (!$awb) {
        continue;
      }
      $shipping_method = $shipment->getShippingMethod();
      if (!$shipping_method) {
        continue;
      }
      $plugin = $shipping_method->getPlugin();
      $tracking = $plugin->getAwbTracking($awb);
      if (!$tracking) {
        continue;
      }
      $tracking_blocks[] = [
        '#theme' => 'item_list',
        '#title' => $this->t('Sameday Tracking for Shipment @id', ['@id' => $shipment->id()]),
        '#items' => array_map(function ($event) {
          return $this->t('@date: @event', ['@date' => $event['date'], '@event' => $event['event']]);
        }, $tracking['history']),
        '#suffix' => '<strong>' . $this->t('Current status: @status', ['@status' => $tracking['status']]) . '</strong>',
      ];
    }
    if (empty($tracking_blocks)) {
      return [
        '#markup' => $this->t('No Sameday tracking information available for this order.'),
      ];
    }
    return $tracking_blocks;
  }

}
