<?php

namespace Drupal\commerce_sameday\Controller;

use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Drupal\Core\Controller\ControllerBase;
use Drupal\commerce_shipping\Entity\ShipmentInterface;

/**
 * Controller for admin Sameday tracking tab.
 */
class SamedayTrackingController extends ControllerBase {

  /**
   * Displays Sameday tracking info for a shipment.
   */
  public function tracking($shipment) {
    if (!$shipment instanceof ShipmentInterface) {
      throw new NotFoundHttpException();
    }
    $awb = $shipment->getData('sameday_awb');
    if (!$awb) {
      return [
        '#markup' => $this->t('No Sameday AWB found for this shipment.'),
      ];
    }
    $shipping_method = $shipment->getShippingMethod();
    if (!$shipping_method) {
      return [
        '#markup' => $this->t('No shipping method found.'),
      ];
    }
    $plugin = $shipping_method->getPlugin();
    $tracking = $plugin->getAwbTracking($awb);
    if (!$tracking) {
      return [
        '#markup' => $this->t('No tracking information available.'),
      ];
    }
    $build = [
      '#theme' => 'item_list',
      '#title' => $this->t('Sameday Tracking History'),
      '#items' => array_map(function ($event) {
        return $this->t('@date: @event', ['@date' => $event['date'], '@event' => $event['event']]);
      }, $tracking['history']),
    ];
    $build['status'] = [
      '#markup' => '<strong>' . $this->t('Current status: @status', ['@status' => $tracking['status']]) . '</strong>',
    ];
    return $build;
  }

}
