<?php

namespace Drupal\Tests\commerce_sameday\Unit\ShippingMethod;

use PHPUnit\Framework\TestCase;

/**
 * Unit tests for SamedayShippingMethod configuration and rates.
 *
 * @group commerce_sameday
 */
class SamedayShippingMethodTest extends TestCase {

  /**
   * Provides a minimal stub for SamedayShippingMethod.
   */
  protected function getStub() {
    return new class {

      /**
       *
       */
      public function defaultConfiguration() {
        return [
          'username' => '',
          'password' => '',
          'client_id' => '',
          'client_secret' => '',
          'sandbox' => TRUE,
        ];
      }

      /**
       *
       */
      public function calculateRates($shipment = NULL) {
        return [
          ['service' => 'test', 'price' => 10],
        ];
      }

    };
  }

  /**
   *
   */
  public function testDefaultConfiguration() {
    $method = $this->getStub();
    $config = $method->defaultConfiguration();
    $this->assertArrayHasKey('username', $config);
    $this->assertArrayHasKey('password', $config);
    $this->assertArrayHasKey('client_id', $config);
    $this->assertArrayHasKey('client_secret', $config);
    $this->assertArrayHasKey('sandbox', $config);
  }

  /**
   *
   */
  public function testCalculateRatesReturnsArray() {
    $method = $this->getStub();
    $rates = $method->calculateRates();
    $this->assertIsArray($rates);
    $this->assertNotEmpty($rates);
    $this->assertArrayHasKey('service', $rates[0]);
    $this->assertArrayHasKey('price', $rates[0]);
  }

}
